MemoryRegistryError

Enum MemoryRegistryError 

pub enum MemoryRegistryError {
    Overlap {
        existing_crate: String,
        existing_start: u8,
        existing_end: u8,
        new_crate: String,
        new_start: u8,
        new_end: u8,
    },
    InvalidRange {
        start: u8,
        end: u8,
    },
    DuplicateId(u8),
    NoReservedRange {
        crate_name: String,
        id: u8,
    },
    IdOwnedByOther {
        crate_name: String,
        id: u8,
        owner: String,
        owner_start: u8,
        owner_end: u8,
    },
    IdOutOfRange {
        crate_name: String,
        id: u8,
    },
    ReservedInternalId {
        id: u8,
    },
}
MemoryRegistryError

Errors returned when a memory range or ID registration is invalid.

Variants



Overlap

A requested owner range overlaps an already reserved range.

Fields

existing_crate: String

Crate that already owns the conflicting range.

existing_start: u8

First ID in the existing range.

existing_end: u8

Last ID in the existing range.

new_crate: String

Crate requesting the new range.

new_start: u8

First ID in the requested range.

new_end: u8

Last ID in the requested range.



InvalidRange

The requested range has start > end.

Fields

start: u8

First ID in the requested range.

end: u8

Last ID in the requested range.



DuplicateId(u8)

The memory ID is already registered.



NoReservedRange

The crate attempted to register an ID before reserving any range.

Fields

crate_name: String

Crate attempting to register the ID.

id: u8

Stable-memory ID being registered.



IdOwnedByOther

The ID falls inside a range reserved by another crate.

Fields

crate_name: String

Crate attempting to register the ID.

id: u8

Stable-memory ID being registered.

owner: String

Crate that owns the range containing id.

owner_start: u8

First ID in the owning range.

owner_end: u8

Last ID in the owning range.



IdOutOfRange

The crate has reserved ranges, but none contain the requested ID.

Fields

crate_name: String

Crate attempting to register the ID.

id: u8

Stable-memory ID being registered.



ReservedInternalId

The ID is reserved for stable-structures internals.

Fields

id: u8

Reserved internal stable-memory ID.